==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/NSLayoutDimension.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSLayoutDimension/*</name>*/ 
    extends /*<extends>*/NSLayoutAnchor<NSLayoutDimension>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSLayoutDimensionPtr extends Ptr<NSLayoutDimension, NSLayoutDimensionPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSLayoutDimension.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSLayoutDimension() {}
    protected NSLayoutDimension(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "constraintEqualToConstant:")
    public native NSLayoutConstraint equalTo(@MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToConstant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(@MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToConstant:")
    public native NSLayoutConstraint lessThanOrEqualTo(@MachineSizedFloat double c);
    @Method(selector = "constraintEqualToAnchor:multiplier:")
    public native NSLayoutConstraint equalTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:multiplier:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintLessThanOrEqualToAnchor:multiplier:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint equalTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/NSLayoutDimension.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSLayoutDimension/*</name>*/ 
    extends /*<extends>*/NSLayoutAnchor<NSLayoutDimension>/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSLayoutDimensionPtr extends Ptr<NSLayoutDimension, NSLayoutDimensionPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSLayoutDimension.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSLayoutDimension() {}
    protected NSLayoutDimension(Handle h, long handle) { super(h, handle); }
    protected NSLayoutDimension(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "constraintEqualToConstant:")
    public native NSLayoutConstraint equalTo(@MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToConstant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(@MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToConstant:")
    public native NSLayoutConstraint lessThanOrEqualTo(@MachineSizedFloat double c);
    @Method(selector = "constraintEqualToAnchor:multiplier:")
    public native NSLayoutConstraint equalTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:multiplier:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintLessThanOrEqualToAnchor:multiplier:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m);
    @Method(selector = "constraintEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint equalTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToAnchor:multiplier:constant:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutDimension anchor, @MachineSizedFloat double m, @MachineSizedFloat double c);
    /*</methods>*/
}
